﻿
using System;
using System.Collections.Generic;
namespace HeuristicLab.Problems.RoutePlanning.Osm {
  #region Highway Types

  // see: https://wiki.openstreetmap.org/wiki/Key:highway
  public enum HighwayType {
    null_type,
    motorway,
    motorway_link,
    trunk,
    trunk_link,
    primary,
    primary_link,
    secondary,
    secondary_link,
    tertiary,
    tertiary_link,
    living_street,
    pedestrian,
    residential,
    unclassified,
    service,
    track,
    bus_guideway,
    raceway,
    road,
    path,
    footway,
    cycleway,
    bridleway,
    steps
  }

  #endregion

  public class Way : OsmBase {
    private List<Node> nodes;

    public Way() {
      nodes = new List<Node>();
    }

    public Way(long id)
      : base(id) {
      nodes = new List<Node>();
    }

    public List<Node> Nodes {
      get { return nodes; }
    }

    private HighwayType highwayTag;
    public HighwayType HighwayTag {
      get {
        if (!base.Tags.ContainsKey(TagConstants.HighwayTagKey)) {
          return HighwayType.null_type;
        }
        if (Enum.IsDefined(typeof(HighwayType), base.Tags[TagConstants.HighwayTagKey])) {
          HighwayType ht = (HighwayType)Enum.Parse(
            typeof(HighwayType),
            base.Tags[TagConstants.HighwayTagKey],
            true);
          return ht;
        } else {
          return HighwayType.null_type;
        }
      }
    }
  }
}
